@@ -420,8 +420,12 @@ class OVNClient(object):
             is_allowed_ips_updated = (sorted(old_allowed_address_pairs) !=
                                       sorted(new_allowed_address_pairs))
 
+            port_security_changed = utils.is_port_security_enabled(port) != (
+                bool(ovn_port.port_security))
+
             # Refresh ACLs for changed security groups or fixed IPs.
-            if detached_sg_ids or attached_sg_ids or is_fixed_ips_updated:
+            if detached_sg_ids or attached_sg_ids or is_fixed_ips_updated or (
+                    port_security_changed):
                 # Note that update_acls will compare the port's ACLs to
                 # ensure only the necessary ACLs are added and deleted
                 # on the transaction.
@@ -1548,7 +1552,7 @@ class OVNClient(object):
         port_dns_records = {}
         for dns_assignment in port.get('dns_assignment', []):
             hostname = dns_assignment['hostname']
-            fqdn = dns_assignment['fqdn']
+            fqdn = dns_assignment['fqdn'].rstrip('.')
             if hostname not in port_dns_records:
                 port_dns_records[hostname] = dns_assignment['ip_address']
             else:
@@ -1607,8 +1611,9 @@ class OVNClient(object):
         for dns_assignment in port['dns_assignment']:
             if dns_assignment['hostname'] not in hostnames:
                 hostnames.append(dns_assignment['hostname'])
-            if dns_assignment['fqdn'] not in hostnames:
-                hostnames.append(dns_assignment['fqdn'])
+            fqdn = dns_assignment['fqdn'].rstrip('.')
+            if fqdn not in hostnames:
+                hostnames.append(fqdn)
 
         for hostname in hostnames:
             if ls_dns_record.records.get(hostname):
