@@ -19,6 +19,7 @@ import tenacity
 
 from neutron_lib.utils import helpers
 from oslo_utils import uuidutils
+from ovsdbapp.backend import ovs_idl
 from ovsdbapp.backend.ovs_idl import connection
 from ovsdbapp.backend.ovs_idl import idlutils
 from ovsdbapp.backend.ovs_idl import transaction as idl_trans
@@ -37,8 +38,6 @@ from networking_ovn.ovsdb import ovsdb_monitor
 
 LOG = log.getLogger(__name__)
 
-from ovsdbapp.backend import ovs_idl
-
 
 # This version of Backend doesn't use a class variable for ovsdb_connection
 # and therefor allows networking-ovn to manage connection scope on its own
@@ -346,23 +345,23 @@ class OvsdbNbOvnIdl(nb_impl_idl.OvnNbApiIdlImpl, Backend):
                                               if_exists)
 
     def _get_logical_router_port_gateway_chassis(self, lrp):
+        """Get the list of chassis hosting this gateway port.
+
+        @param   lrp: logical router port
+        @type    lrp: Logical_Router_Port row
+        @return: List of tuples (chassis_name, priority)
+        """
         # Try retrieving gateway_chassis with new schema. If new schema is not
         # supported or user is using old schema, then use old schema for
         # getting gateway_chassis
         chassis = []
         if self._tables.get('Gateway_Chassis'):
             for gwc in lrp.gateway_chassis:
-                # TODO(anilvenkata): Add to the list based on priority.
-                # Otherwise, if lrp1 is scheduled on c1 with priority 1 and c2
-                # with priority 2. When new port lrp2 is scheduled, it is also
-                # scheduled on c1 with priority 1 and c2 with priority 2.
-                # If we add to the list based on priority then it will be
-                # scheduled on c1 with priority 2 and on c2 with priority 1.
-                chassis.append(gwc.chassis_name)
+                chassis.append((gwc.chassis_name, gwc.priority))
         else:
             rc = lrp.options.get(ovn_const.OVN_GATEWAY_CHASSIS_KEY)
             if rc:
-                chassis.append(rc)
+                chassis.append((rc, 0))
         return chassis
 
     def get_all_chassis_gateway_bindings(self,
@@ -374,19 +373,20 @@ class OvsdbNbOvnIdl(nb_impl_idl.OvnNbApiIdlImpl, Backend):
             if not lrp.name.startswith('lrp-'):
                 continue
             chassis = self._get_logical_router_port_gateway_chassis(lrp)
-            for chassis_name in chassis:
+            for chassis_name, prio in chassis:
                 if (not chassis_candidate_list or
                         chassis_name in chassis_candidate_list):
                     routers_hosted = chassis_bindings.setdefault(chassis_name,
                                                                  [])
-                    routers_hosted.append(lrp.name)
+                    routers_hosted.append((lrp.name, prio))
         return chassis_bindings
 
     def get_gateway_chassis_binding(self, gateway_name):
         try:
             lrp = idlutils.row_by_value(
                 self.idl, 'Logical_Router_Port', 'name', gateway_name)
-            return self._get_logical_router_port_gateway_chassis(lrp)
+            chassis_list = self._get_logical_router_port_gateway_chassis(lrp)
+            return [chassis for chassis, prio in chassis_list]
         except idlutils.RowNotFound:
             return []
 
@@ -398,8 +398,8 @@ class OvsdbNbOvnIdl(nb_impl_idl.OvnNbApiIdlImpl, Backend):
             if not lrp.name.startswith('lrp-'):
                 continue
             physnet = port_physnet_dict.get(lrp.name[len('lrp-'):])
-            for chassis_name in self._get_logical_router_port_gateway_chassis(
-                    lrp):
+            chassis_list = self._get_logical_router_port_gateway_chassis(lrp)
+            for chassis_name, prio in chassis_list:
                 # TODO(azbiswas): Handle the case when a chassis is no
                 # longer valid. This may involve moving conntrack states,
                 # so it needs to discussed in the OVN community first.
@@ -443,8 +443,8 @@ class OvsdbNbOvnIdl(nb_impl_idl.OvnNbApiIdlImpl, Backend):
         ret_opts = []
         for row in self._tables['DHCP_Options'].rows.values():
             external_ids = getattr(row, 'external_ids', {})
-            if (external_ids.get('subnet_id') in subnet_ids
-                    and not external_ids.get('port_id')):
+            if (external_ids.get('subnet_id') in subnet_ids and not
+                    external_ids.get('port_id')):
                 ret_opts.append(self._format_dhcp_row(row))
                 if len(ret_opts) == len(subnet_ids):
                     break
@@ -746,8 +746,7 @@ class OvsdbSbOvnIdl(sb_impl_idl.OvnSbApiIdlImpl, Backend):
         return [r for r in rows if r.chassis and r.chassis[0].name == chassis]
 
     def get_logical_port_chassis_and_datapath(self, name):
-        rows = self.db_list_rows('Port_Binding').execute(check_error=True)
-        for port in rows:
+        for port in self._tables['Port_Binding'].rows.values():
             if port.logical_port == name:
                 datapath = str(port.datapath.uuid)
                 chassis = port.chassis[0].name if port.chassis else None
